/*------------------------------------------------------------------------
 
  File: schupd2a.p

  Description: Assign storage area number to metaschema fields
               during schema update.
               
               This file is separate from other schema update logic
               as the user may be updating a pre-V9 DB, in which case
               these statements would not compile, since storage area
               metaschema fields would not be supported.
              
  Input Parameters:
      Ptype - Update type ("File","Index", or "LOB") AS CHAR
      Parea  - Storage area name AS CHARACTER.

  Output Parameters:
      <none>

  Created: Sept 1998

------------------------------------------------------------------------*/
DEFINE INPUT PARAMETER Ptype AS CHARACTER NO-UNDO.
DEFINE INPUT PARAMETER Parea AS CHARACTER NO-UNDO.

DEFINE VARIABLE iAreaNum AS INTEGER NO-UNDO.

DEFINE SHARED BUFFER Bfile  FOR DICTDB._file.
DEFINE SHARED BUFFER Bindex FOR DICTDB._index.
DEFINE SHARED BUFFER Bfield FOR DICTDB._field.

/* 
 Get associated _Area record.
 
 If the area name does not exist in the database, the default shema
 area (6) is used.
*/
FIND DICTDB._Area WHERE DICTDB._Area._Area-name = Parea NO-LOCK NO-ERROR.
iAreaNum = (IF AVAILABLE DICTDB._Area THEN
              DICTDB._Area._Area-number
            ELSE
              6).

CASE Ptype:

  WHEN "File":U THEN
    Bfile._ianum = iAreaNum.

  WHEN "Index":U THEN
      Bindex._ianum = iAreaNum.
      
  WHEN "LOB":U THEN
      Bfield._Fld-stlen = iAreaNum.
      
END CASE.

RETURN.
